@@ -7,8 +7,8 @@
 ;; Created: October 31, 2020
 ;; URL: https://github.com/shg/ob-julia-vterm.el
 ;; Package-Requires: ((emacs "26.1") (julia-vterm "0.26") (queue "0.2"))
-;; Package-Version: 0.11
-;; Package-Revision: bc0f851d4a64
+;; Package-Version: 20251226.916
+;; Package-Revision: dbcabdf4502a
 ;; Keywords: julia, org, outlines, literate programming, reproducible research
 
 ;; This file is not part of GNU Emacs.
@@ -410,6 +410,15 @@ With prefix ARG, prompt for session name."
   (interactive)
   (julia-vterm-send-region-or-current-line))
 
+(defun ob-julia-vterm-helper-handle-tab ()
+  "Perform latex substitution or indentation in a Julia source block."
+  (interactive)
+  (if (and (org-in-src-block-p t)
+           (string= (car (org-babel-get-src-block-info)) "julia"))
+      (save-restriction
+        (org-narrow-to-block)
+        (call-interactively #'julia-latexsub-or-indent))))
+
 (defvar ob-julia-vterm-helper-mode-map
   (let ((map (copy-keymap julia-vterm-mode-map)))
     (define-key map (kbd "C-c C-z") #'ob-julia-vterm-switch-to-repl-buffer)
@@ -425,7 +434,10 @@ With prefix ARG, prompt for session name."
   :lighter " ⁂"
   :keymap ob-julia-vterm-helper-mode-map
   (unless (eq major-mode 'org-mode)
-    (user-error "Cannot use `ob-julia-vterm-helper-mode' outside Org mode")))
+    (user-error "Cannot use `ob-julia-vterm-helper-mode' outside Org mode"))
+  (if ob-julia-vterm-helper-mode
+      (add-hook 'org-tab-first-hook #'ob-julia-vterm-helper-handle-tab 0 t)
+    (remove-hook 'org-tab-first-hook #'ob-julia-vterm-helper-handle-tab t)))
 
 (unless (fboundp 'julia-helper-mode)
   (defalias 'julia-helper-mode 'ob-julia-vterm-helper-mode))
